use image::DynamicImage;
use imageproc::filter::gaussian_blur_f32;

use crate::config::image_processors::ProcessorParams;
use crate::result::MBGResult;

use super::ImageProcessor;

pub struct BlurProcessor {
    pub params: ProcessorParams,
}

impl ImageProcessor for BlurProcessor {
    fn process(&self, img: &DynamicImage) -> MBGResult<DynamicImage> {
        debug!("Blurring image with sigma: {}", self.params.strength);
        Ok(DynamicImage::ImageRgba8(gaussian_blur_f32(
            &img.to_rgba(),
            self.params.strength,
        )))
    }
}
